@@ -5,10 +5,12 @@ import sys
 
 from .hub import Hub
 from .client import Client
-from .core.backend import activate_greenhouse, activate_gevent, activate_eventlet
+from .core.backend import \
+        activate_greenhouse, activate_gevent, activate_eventlet
+from .futures import Future, after, wait_any
 
 
-VERSION = (1, 0, 4, "")
+VERSION = (2, 0, 0, "")
 __version__ = ".".join(filter(None, map(str, VERSION)))
 
 
