@@ -58,6 +58,7 @@ def gevent_schedule(target=None, args=(), kwargs=None):
         gevent.spawn(target, *args, **(kwargs or {}))
     return target
 
+
 def gevent_schedule_in(secs, target=None, args=(), kwargs=None):
     if target is None:
         def decorator(target):
@@ -69,9 +70,11 @@ def gevent_schedule_in(secs, target=None, args=(), kwargs=None):
         gevent.spawn_later(secs, target, *args, **(kwargs or {}))
     return target
 
+
 def gevent_schedule_exception(exception, target):
     gevent.kill(target, exception)
 
+
 def gevent_greenlet(func, args=(), kwargs=None):
     return gevent.Greenlet(func, *args, **(kwargs or {}))
 
@@ -82,6 +85,7 @@ if gevent:
 else:
     gevent_event = None
 
+
 def activate_gevent():
     globals()['Socket'] = gevent.socket.socket
     globals()['Queue'] = gevent.queue.Queue
@@ -107,6 +111,7 @@ def eventlet_schedule(target=None, args=(), kwargs=None):
         eventlet.spawn(target, *args, **(kwargs or {}))
     return target
 
+
 def eventlet_schedule_in(secs, target=None, args=(), kwargs=None):
     if target is None:
         def decorator(target):
@@ -116,12 +121,15 @@ def eventlet_schedule_in(secs, target=None, args=(), kwargs=None):
         eventlet.spawn_after(secs, target, *args, **(kwargs or {}))
     return target
 
+
 def eventlet_schedule_exception(exception, target):
     eventlet.hubs.get_hub().schedule_call_global(0, target.throw, exception)
 
+
 def eventlet_greenlet(func, args=(), kwargs=None):
     return eventlet.spawn(func, *args, **(kwargs or {}))
 
+
 class eventlet_event(object):
     def __init__(self):
         self._waiters = []
@@ -140,6 +148,10 @@ class eventlet_event(object):
     def clear(self):
         self._is_set = False
 
+    def is_set(self):
+        return self._is_set
+    isSet = is_set
+
     def wait(self, timeout=None):
         if self._is_set:
             return False
@@ -167,6 +179,7 @@ class eventlet_event(object):
             self._waiters.remove(waiter)
             eventlet.hubs.get_hub().schedule_call_global(0, waiter.switch)
 
+
 def activate_eventlet():
     globals()['Socket'] = eventlet.greenio.GreenSocket
     globals()['Queue'] = eventlet.green.Queue.Queue
