@@ -156,7 +156,8 @@ class Dispatcher(object):
                 peer.established.set()
                 return False
         elif peer.ident in self.reconnecting and not peer.initiator:
-            log.info("terminating reconnect loop in favor of incoming conn")
+            log.info("terminating reconnect loop in favor of incoming "
+                    "connection")
             loser = self.reconnecting.pop(peer.ident)
 
         peer.established.set()
@@ -389,7 +390,7 @@ class Dispatcher(object):
         return self.rpc_client.request(
                 [self.peers.values()[0]],
                 (service, routing_id, method, bool(singular), args, kwargs),
-                singular)
+                singular)[1]
 
     def target_selection(self, peers, service, routing_id, method):
         by_addr = {}
@@ -443,8 +444,8 @@ class Dispatcher(object):
                 backend.schedule(glet)
             return rpc
 
-        return self.rpc_client.request(
-                routes, (service, routing_id, method, args, kwargs), singular)
+        return self.rpc_client.request(routes,
+                (service, routing_id, method, args, kwargs), singular)[1]
 
     def send_chunked_rpc(self, service, routing_id, method, args, kwargs,
             targets, counter, singular=False, proxied=False):
@@ -506,7 +507,8 @@ class Dispatcher(object):
             msgtype += 9
 
         msg = (counter, ident)
-        if not proxied: msg = msg[0]
+        if not proxied:
+            msg = msg[0]
         peer.push((msgtype, msg))
 
         chunks = iter(chunks)
@@ -546,13 +548,13 @@ class Dispatcher(object):
 
         if not err:
             msg = (counter, ident)
-            if not proxied: msg = msg[0]
+            if not proxied:
+                msg = msg[0]
             peer.push((msgtype + 6, msg))
 
         self.unregister_outgoing_channel([peer],
                 const.MSG_TYPE_RESPONSE_IS_CHUNKED, counter)
 
-
     def send_proxied_publish(self, service, routing_id, method, args, kwargs,
             singular=False):
         log.debug("sending proxied_publish %r" %
@@ -910,10 +912,10 @@ class Dispatcher(object):
             log.debug("forwarding proxy_request %r to %d peers" %
                     (msg[:4], target_count - bool(handler)))
 
-            rpc = self.rpc_client.request(
+            counter, rpc = self.rpc_client.request(
                     targets, (service, routing_id, method, args, kwargs))
 
-            self.inflight_proxies[rpc.counter] = {
+            self.inflight_proxies[counter] = {
                 'awaiting': len(targets),
                 'client_counter': cli_counter,
                 'peer': peer,
@@ -1525,6 +1527,7 @@ class LocalTarget(object):
     # there's no issue with unserializable arguments (or return values). so
     # we'll skip the "dump" phase and just "push" the object itself
     push_string = push
+
     def dump(self, msg):
         return msg
 
