@@ -50,7 +50,8 @@ class Hub(object):
             remaining = max(0, deadline - time.time()) if timeout else None
             if not self._started_peers[peer_addr].wait_connected(remaining):
                 if timeout:
-                    log.warn("connect wait timed out after %.2f seconds" % timeout)
+                    log.warn("connect wait timed out after %.2f seconds" %
+                            timeout)
                 return False
         return True
 
@@ -179,7 +180,8 @@ class Hub(object):
             return peers + 1
         return peers
 
-    def accept_rpc(self, service, mask, value, method, handler=None, schedule=True):
+    def accept_rpc(self, service, mask, value, method,
+            handler=None, schedule=True):
         '''Set a handler for incoming RPCs
 
         :param service: the incoming RPC must have this service
@@ -284,33 +286,6 @@ class Hub(object):
 
         return rpc
 
-    def wait_any(self, futures, timeout=None):
-        '''Wait for the response for any (the first) of multiple futures
-
-        This method will block until a response has been received.
-
-        :param futures:
-            a list made up of :class:`rpc <junction.futures.RPC>` and
-            :class:`Dependent <junction.futures.Dependent>` objects
-        :type futures: list
-        :param timeout:
-            maximum time to wait for a response in seconds. with None, there is
-            no timeout.
-        :type timeout: float or None
-
-        :returns:
-            one of the :class:`RPC <junction.futures.RPC>`\s or
-            :class:`Dependent <junction.futures.Dependent>`\s from ``futures``
-            -- the first one to be completed (or any of the ones that were
-            already completed) for which the ``completed`` attribute is
-            ``True``.
-
-        :raises:
-            - :class:`WaitTimeout <junction.errors.WaitTimeout>` if a timeout
-              was provided and it expires
-        '''
-        return self._rpc_client.wait(futures, timeout)
-
     def rpc(self, service, routing_id, method, args=None, kwargs=None,
             timeout=None, singular=False):
         '''Send an RPC request and return the corresponding response
@@ -349,8 +324,10 @@ class Hub(object):
             - :class:`WaitTimeout <junction.errors.WaitTimeout>` if a timeout
               was provided and it expires
         '''
-        return self.send_rpc(service, routing_id, method,
-                args or (), kwargs or {}, singular).wait(timeout)
+        rpc = self.send_rpc(service, routing_id, method,
+                args or (), kwargs or {}, singular)
+        rpc.wait(timeout)
+        return rpc.value
 
     def rpc_receiver_count(self, service, routing_id):
         '''Get the number of peers that would handle a particular RPC
@@ -371,27 +348,6 @@ class Hub(object):
             return peers + 1
         return peers
 
-    def dependency_root(self, func):
-        '''Create a parent-less :class:`Dependent <junction.futures.Dependent>`
-
-        This is like :meth:`RPC.after <junction.futures.RPC.after>` or
-        :meth:`Dependent.after <junction.futures.Dependent.after>` in that it
-        wraps a callback with a new :class:`Dependent
-        <junction.futures.Dependent>`, but this one has no parents (so the
-        callback should take no arguments).
-
-        :param func:
-            the callback function for the dependent (this will be started
-            immediately in a separate coroutine)
-        :type func: callable
-
-        :returns: a new :class:`Dependent <junction.futures.Dependent>`
-        '''
-        client = self._rpc_client
-        dep = futures.Dependent(client, client.next_counter(), [], func)
-        dep._complete()
-        return dep
-
     def start(self):
         "Start up the hub's server, and have it start initiating connections"
         log.info("starting")
@@ -409,6 +365,12 @@ class Hub(object):
         peer.start()
         self._started_peers[peer_addr] = peer
 
+    @property
+    def peers(self):
+        "list of the (host, port) pairs of all connected peer Hubs"
+        return [addr for (addr, peer) in self._dispatcher.peers.items()
+                if peer.up]
+
     def _listener(self):
         server = backend.Socket()
         server.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
